@@ -91,7 +91,7 @@ def get_auto_most(geom_a, geom_b, latitude='north'):
     latitude = latitude_lower in ['north', 'south']
     return get_extremity(geom_a, geom_b, latitude=latitude)
 
-def get_geom_range(geom_a, geom_b, latitude='north', rangeInclusiveA=False, rangeInclusiveB=False,strictA=False,strict_B=False):
+def get_geom_range(geom_a, geom_b, latitude='north', rangeInclusiveA=False, rangeInclusiveB=False,strictA=False,strictB=False):
     """
     Determine the range between two geometries based on the specified direction.
 
@@ -114,7 +114,7 @@ def get_geom_range(geom_a, geom_b, latitude='north', rangeInclusiveA=False, rang
 
     return {
         "latitude": [auto_js['min']['direction'], auto_js['max']['direction']],
-        "strict":[reference_js[auto_js['min']['geom']]['strict'],reference_js[auto_js['max']['geom']]['strict']],
+        "strict":[bool(reference_js[auto_js['min']['geom']]['strict']),bool(reference_js[auto_js['max']['geom']]['strict'])],
         "range": [
             get_position_of_geom(reference_js[auto_js['min']['geom']]["geom"], r=r_b, latitude=auto_js['min']['direction']),
             get_position_of_geom(reference_js[auto_js['max']['geom']]["geom"], r=r_a, latitude=auto_js['max']['direction'])
@@ -122,32 +122,41 @@ def get_geom_range(geom_a, geom_b, latitude='north', rangeInclusiveA=False, rang
     }
 
 # Function to check if a geometry's latitude lies within specified bounds, supporting both Polygon and MultiPolygon
-def is_within_bounds(geometry, geom_range):
-    def extract_latitudes(polygon):
+def is_geom_within_bounds(geometry, geom_range):
+    def extract_latitudes(polygon,latitude):
         """Extract latitudes from a polygon's exterior coordinates."""
         return [coord_extractor(coord,latitude=latitude) for coord in polygon.exterior.coords]
     
-    lower_bound,upper_bound=coord_extractor(geom_range["range"][0],geom_range["latitude"][0])mcoord_extractor(geom_range["range"][1],geom_range["latitude"][1])
-    geom_range["strict"][0] = bool(geom_range["strict"][0])
-    geom_range["strict"][1]=bool(geom_range["strict"][1])
-    
+    lower_bound,upper_bound=coord_extractor(geom_range["range"][0],geom_range["latitude"][0]),coord_extractor(geom_range["range"][1],geom_range["latitude"][1])
     latitudes = []
-    if isinstance(geometry, Polygon):
-        latitudes = extract_latitudes(geometry)
-    elif isinstance(geometry, MultiPolygon):
-        for polygon in geometry.geoms:
-            latitudes.extend(extract_latitudes(polygon))
-    else:
-        raise TypeError("Unsupported geometry type")
+    for i,lattitude in enumerate(geom_range["latitude"]):
+        if i==1 and lattitude==geom_range["latitude"][0]:
+            latitudes+=latitudes
+            break
+        if isinstance(geometry, Polygon):
+            latitudes = extract_latitudes(geometry,lattitude)
+        elif isinstance(geometry, MultiPolygon):
+            for polygon in geometry.geoms:
+                latitudes.extend(extract_latitudes(polygon,lattitude))
+        else:
+            raise TypeError("Unsupported geometry type")
     if geom_range["strict"][0] and geom_range["strict"][1]:
-        if any((lower_bound > lat or upper_bound < lat) for lat in latitudes):
-            return False   
+        if lattitudes[0]==lattitudes[1]:
+            if any((lower_bound > lat or upper_bound < lat) for lat in latitudes):
+                return False
+        else:
+            if any(lower_bound > lat for lat in lattitudes[0]) or any(higher_bound < lat for lat in lattitudes[1]):
+                return False   
     elif geom_range["strict"][0] and not geom_range["strict"][1]:
-        if any(lower_bound > lat for lat in latitudes):
+        if any(lower_bound > lat for lat in lattitudes[0]):
             return False
     elif geom_range["strict"][1] and not geom_range["strict"][0]:
-        if any(upper_bound < lat for lat in latitudes):
+        if any(upper_bound < lat for lat in lattitudes[1]):
             return False
     # Check if any latitude falls within the specified bounds
-    return any(lower_bound <= lat <= upper_bound for lat in latitudes)
-
+    else:
+         if lattitudes[0]==lattitudes[1]:
+            return any(lower_bound <= lat <= upper_bound for lat in latitudes)
+         else:
+             return (any(ulower_bound <= lat for lat in lattitudes[0]) and any(lat  <= upper_bound for lat in lattitudes[1]))
+    return False
